@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
 """bootstrap_py.docs."""
+import os.path
 import shlex
 import subprocess
 
 
 def build_sphinx(pkg_data, projectdir):
-    """Building sphinx documentation.
+    """Build sphinx documentation.
 
     :rtype: int
     :return: subprocess.call return code
@@ -13,9 +14,9 @@ def build_sphinx(pkg_data, projectdir):
     :param `bootstrap_py.control.PackageData` pkg_data: package meta data
     :param str projectdir: project root directory
     """
-    if len(pkg_data.version.rsplit('.', 1)) > 0:
-        version = pkg_data.version.rsplit('.', 1)[1]
-    else:
+    try:
+        version, _minor_version = pkg_data.version.rsplit('.', 1)
+    except ValueError:
         version = pkg_data.version
     args = ' '.join(('sphinx-quickstart',
                      '--sep',
@@ -35,4 +36,13 @@ def build_sphinx(pkg_data, projectdir):
                                              version=version,
                                              release=pkg_data.version,
                                              projectdir=projectdir)
-    return subprocess.call(shlex.split(args))
+    if subprocess.call(shlex.split(args)) == 0:
+        _touch_gitkeep(projectdir)
+
+
+def _touch_gitkeep(docs_path):
+    with open(os.path.join(docs_path,
+                           'source',
+                           '_static',
+                           '.gitkeep'), 'w') as fobj:
+        fobj.write('')
