@@ -5,7 +5,7 @@ from defusedxml.ElementTree import fromstring
 from bootstrap_py import __version__
 
 
-class Update(object):
+class Update:
     """bootstrap-py updata checker."""
 
     badge_url = 'https://img.shields.io/pypi/v/bootstrap-py.svg'
@@ -17,7 +17,10 @@ class Update(object):
         self.latest_version = self._latest_version()
 
     def _latest_version(self):
-        resp = requests.get(self.badge_url)
+        try:
+            resp = requests.get(self.badge_url)
+        except requests.exceptions.ConnectionError:
+            return '0.0.0'
         element_tree = fromstring(resp.text)
         return element_tree.findall(
             '{ns}g'.format(ns=self.name_space))[1].findall(
@@ -26,9 +29,10 @@ class Update(object):
     def updatable(self):
         """bootstrap-py package updatable?."""
         if self.latest_version > self.current_version:
-            return self.latest_version
+            updatable_version = self.latest_version
         else:
-            return False
+            updatable_version = False
+        return updatable_version
 
     def show_message(self):
         """Show message updatable."""
